@@ -8,7 +8,7 @@ require DynaLoader;
 
 @ISA = qw(Exporter DynaLoader);
 @EXPORT = qw(statvfs);
-$VERSION = '0.70';
+$VERSION = '0.72';
 bootstrap Filesys::Statvfs $VERSION;
 
 1;
@@ -26,29 +26,19 @@ Filesys::Statvfs - Perl extension for statvfs().
 	$files, $ffree, $favail, $fsid, $basetype, $flag,
 	$namemax, $fstr) = statvfs("/tmp");
 
-	##### On HP-UX 10x systems f_time and f_size are avaliable
-
-	($bsize, $frsize, $blocks, $bfree, $bavail,
-	$files, $ffree, $favail, $fsid, $basetype, $flag,
-	$namemax, $fstr, $size, $time) = statvfs("/tmp");
-
-
-
 =head1 DESCRIPTION
 
 Interface for statvfs();
 
 The statvfs() function will return a list
-of values or will return undef and 
-set $! if there was an error.
+of values or will return undef and set $!
+if there was an error.
 
 The values returned are described in the statvfs header or
 the statvfs() man page.
 
 Note:
-On Digital Unix $fstr will be NULL.
-
-$size and $time are only returned on HP-UX systems.
+On Digital Unix and Linux $fstr will be NULL.
 
 =head1 AUTHOR
 
